# Planar Ignition

Planar Ignition (PI) is a Planechase variant for 3+ players, primarily aimed at Commander games (where "have fun" is king). It is designed to take some of the best aspects from the original Planechase rules and the Planar Map variant, as well as some new aspects, to provide a very flavourful, enjoyable, and practical play experience.

## What Planar Ignition is trying to do

Some of the problems inherent to the original Planechase are...

* Each player managing a planar deck is a pain; a shared deck is nice with a single play organizer.
* Excessive randomness; players knowing where they're going is more flavourful and enjoyable, and while Phenomenons are cool they just add to this.
* Lack of control; players want a choice, which the original rules don't provide.

And simiarly, for the Planar Map variant...

* Requires a large amount of table space and constant moving of big cards; ideally there is a smaller subset of Planar cards on the field at once.
* Looping back and forth between planes (or the threat of it) is annoying; once a plane is left, it should be gone for a while.
* Still too much randomness; it is possible that all 4 choices suck for a given player, which is an unfun game experience.
* Hellriding is good for getting out of the above tight spots and is flavourful, but less practical physically; we want something *like* hellriding without the complexity.

Planar Ignition tries to solve all of these pain points by...

* Giving each player a very small, non-random "planar pool" instead of a deck.
* Providing players an *active choice* about their next destination, which is a flavour win, but still limited in changes (only allowing a destination change on a blank planar die roll or after a planeswalk clears an open destination).
* Keeping the number of revealed destinations to the minimum of 1-per-player, reducing board space requirements.
* Removing looping and keeping forward momentum through a "planar cooldown" rule (planes returned to a planar pool after a planeswalk can't be immediately chosen as a destination).

## How To Play Planar Ignition

### Planar Card Selection

For Planar Ignition to work properly, a few Planar cards are either outright disallowed or recommended to be avoided:

* All Phenomenons. These do not work properly in a "revealed destination" variant.
* Norn's Seedcore. The practical effect of this plane is just too insane to work properly in this variant. It is the only explicitly *banned* plane.
* Aretopolis, Bad Wolf Bay, Grand Ossuary, Lair of the Ashen Idol, Pompeii, TARDIS Bay: These planes all feature some form of "then planeswalk." effect. This doesn't work very well in Planar Ignition, but can be worked around by either avoiding these planes or removing the "then planeswalk." part of the effects.

### Pre-Game

*Note:* All explanations below assume a 4 player game for simplicity.

* Decide on decks as a playgroup. Then, from among all available Plane cards, each player selects between three (3) and five (5) planes that complement their deck and strategy; all players must choose the same number:
   * One (1) "home plane" which will be their starting plane.
   * The remaining planes are "secondary planes" which they may want to go to.

   Note that these distinctions only really matter at the start of the game; once a player's "home plane" returns to their planar pool (below), there is no longer anything special about it.

   The total number of planes for each player should remain relatively small, with no more than 5 per player. This helps prevent choice paralysis and keep things manageable for all players.

   Different players may, if the available Plane cards support it, choose the same plane(s) for their planar pools. This is of course subject to rule 0, and if there are not two of the same Plane card, this is impossible. Decide amongst yourselves when starting the game, but remember to keep it interesting (don't let everyone pick the same planes over and over)!

* After deciding turn order but before drawing opening/taking mulligans, select the starting plane. If using an "Archenemy" game mode, the Archenemy should be the planar decider; otherwise, each player in turn order rolls the planar die, proceeding until a player hits the "planeswalk" symbol. That player becomes the planar decider.

* The planar decider's "home plane" will be the starting plane for the game, active from turn 0. Each other player's "home plane" becomes one of the initial possible destinations. The planar decider does not get a destination to start, only getting a destination after the first planeswalk; thus the first destination round will always have 1 fewer plane than there are players. Place them face-up above the starting plane like so:

```
                  |---------| |---------| |---------| |---------|
Destination row:  | P1 .... | | P2 Home | | P3 Home | | P4 Home |
                  |---------| |---------| |---------| |---------|

                                    |---------|
Active row:                         | P1 Home |
                                    |---------|
```

  Yes, this means that the planar decider has nowhere (they *want*) to planeswalk; that's the tradeoff of picking the starting plane, you don't really "get" to planeswalk (at least, not to one of *your* planes) until someone else does (though, see below)!

* Each player's remaining planes become their "planar pool". Each player has a separate planar pool, and these are not shuffled or hidden from the player. A player may look at their planar pool at any time.

* Begin the Magic game proper.

### Playing The Game

* The original planar die rolling rules remain the same (players may roll once for free then pay {1} for each previous roll to roll again as many times as they can afford each turn).

* The original 2 planar die functions ("Planeswalk" and "Chaos Ensues") remain the same. If chaos ensues, the normal rules apply. If planeswalking happens, see the section "Planeswalking" below.

* A 3rd planar die function is added. On any *blank* roll of the die, the player may select a new destination plane, replacing their current destination plane. This is the only time changing a destination plane is allowed, so you must risk a planeswalk (forcing you somewhere you may not want to go right now) or chaos to change your planned destination!

### Planeswalking

* Upon a planeswalk, that player chooses one of the 3 (first planeswalk) or 4 (subsequent planeswalks) available destination planes to planeswalk to. Usually, this will be their own destination plane, but you never know where the game might take you, and you *can* select another player's plane to planeswalk to, should that suit you best!

* After selecting the destination, the current active plane is returned to its player's planar pool. Then, the selected plane becomes the next active plane, moving from the Destination row to the Active row.

* Immediately, the player who's plane was selected chooses a new destination plane and places it in the destination row. Additionally, if this is the first planeswalk, the starting plane's player also chooses a destination plane and places it in the destination row. The plane that is being left *cannot* be chosen as the destination by its player; they must choose another plane from their planar pool. This is the "planar cooldown" rule.

* Any effects (static or "when you planeswalk to") for the new active plane trigger and go on the stack. The turn continues as normal.

## Example Playthrough

Four players, Alice, Bob, Carol, and Erin, begin playing. Each selects a pool of 3 planes. Those planes are (note that these are nonsensical choices based on letter only, don't worry about it):

* Alice: Agyrem (home), Akoum, Aretopolis
* Bob: Bant (home), Bloodhill Bastion ("Bastion" for short),  Bowie Base One ("Base" for short)
* Carol: Celestine Reef (home, "Celestine" for short), Cliffside Market ("Cliffside" for short), Coal Hill School ("CHSc" for short)
* Erin: Eloren Wilds (home, "Eloren" for short), Enigma Riges ("Enigma" for short), Esper

Alice goes first for turn order, so starting with Alice, each player rolls the planar die. After a few rounds, Bob rolls "planeswalk" on the planar die, and thus becomes the planar decider.

Bob's home plane (Bant) becomes the starting active plane, while the remaining 3 players' home planes become the initial destinations. Thus the planar board looks like this; note Bob's space is empty:

```
|--------| |-------| |-----------| |--------|
| Agyrem | |       | | Celestine | | Eloren |
|--------| |-------| |-----------| |--------|

                |------|
                | Bant |
                |------|
```

After a few turns of land-pass, things start to get interesting on Carol's turn. She's thinking she might rather be on Coal Hill School rather than Celestine Reef, but to change her destination she must roll the planar die.

Carol rolls for {0} and gets a blank face. This enables her to change her destination as desired. Celestine Reef returns to Carol's planar pool, and Coal Hill School takes its place in her destination plane spot:

```
|--------| |-------| |--------| |--------|
| Agyrem | |       | |  CHSc  | | Eloren |
|--------| |-------| |--------| |--------|

                |------|
                | Bant |
                |------|
```

Carol still has some mana, so she decides to roll again for {1}. She gets lucky, and lands on "planeswalk", deciding that she indeed wants to planeswalk to Coal Hill School.

First, Bant returns to Bob's planar pool, and Coal Hill School becomes the active plane:

```
|--------| |-------| |-------| |--------|
| Agyrem | |       | |       | | Eloren |
|--------| |-------| |-------| |--------|

                |------|
                | CHSc |
                |------|
```

Second, both Bob and Carol simultaneously choose a new destination plane from their planar pools. Note that Bob *cannot* choose Bant as his destination due to the "planar cooldown" rule; he must choose one of his other 2 planes. Bob selects Bowie Base One and Carol selects Cliffside Market:

```
|--------| |------| |-----------| |--------|
| Agyrem | | Base | | Cliffside | | Eloren |
|--------| |------| |-----------| |--------|

                |------|
                | CHSc |
                |------|
```

At this point, play continues as normal. Chaos ensues actions happen as they would in any other Planechase variant.

Later in the game, Erin is in a tricky spot. She wants Agyrem's effects, even more so than any of her own planes' effects. So, she tries for it and after a few dud rolls, she hits "planeswalk" and picks Agyrem as the destination:

```
|--------| |------| |-----------| |--------|
|        | | Base | | Cliffside | | Eloren |
|--------| |------| |-----------| |--------|

               |--------|
               | Agyrem |
               |--------|
```

Now, it's not Erin picking a new destination plane from her pool, but Alice, even though it was Erin who planeswalked! Alice picks Akoum:

```
|-------| |------| |-----------| |--------|
| Akoum | | Base | | Cliffside | | Eloren |
|-------| |------| |-----------| |--------|

              |--------|
              | Agyrem |
              |--------|
```

Erin passes, and play continues. The process above will repeat on each planeswalk until the game ends.
